@@ -1,11 +1,11 @@
 #!/bin/bash
-#This script starts the CCServer afer the RMI registery is started in 
+#This script starts the CCServer after the RMI registery is started in 
 #the background.
 
 #The location of JRE directory
-J_HOME=/usr/local/jdk117
+J_HOME=/usr/lib/java
 
 #The location of ChemConsoleServer directory
-CS_HOME=/home/nath/Jfc/CCS-0.3
+CS_HOME=/home/nathan/Jfc/CCS-0.4
  
 jre -classpath $J_HOME/lib/classes.zip:$CS_HOME:$CS_HOME/CCServer.jar:$CS_HOME/rmic CCServerManager $1 
